#
# spec file for package python-compizconfig
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
%define _rev    11bb53f9054e95f715e631a261968e2c
%define _name   compizconfig-python
Name:           python-compizconfig
Version:        0.8.18
Release:        bp153.1.22
Summary:        Python bindings for libraries for compizconfig-settings
License:        GPL-2.0-or-later
URL:            https://gitlab.com/compiz/compizconfig-python
Source:         https://gitlab.com/compiz/compizconfig-python/uploads/%{_rev}/%{_name}-%{version}.tar.xz
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module devel}
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(libcompizconfig) < 0.9
BuildRequires:  pkgconfig(x11)
Requires:       compiz < 0.9
%python_subpackages

%description
Python bindings for libraries/plugins for compizconfig-settings.

%prep
%setup -q -n %{_name}-%{version}

%build
NOCONFIGURE=1 ./autogen.sh
%global _configure ../configure
%{python_expand mkdir -p "build-$python"
pushd "build-$python"
export PYTHON="$python"
%configure \
  --disable-static \
  --with-cython="cython-%{$python_version}"
%make_build
popd
}

%install
%python_expand %make_install -C "build-$python"

find %{buildroot} -type f -name "*.la" -delete -print
rm -r %{buildroot}%{_libdir}/pkgconfig/

%files %{python_files}
%license COPYING
%doc NEWS README.md
%{python_sitearch}/compizconfig*

%changelog
* Tue Apr 28 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Skip building with Python 2 as depenedency requirements no longer
  met for it.
* Sat Apr  4 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 0.8.18:
  * Do not bundle the generated C file with the tarball.
* Mon Apr  8 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Fix Python 3.7 compatibility issues by removing pre-generated
  compizconfig.c (glc#compiz/compiz-core#146).
* Sun Nov 11 2018 sor.alexei@meowr.ru
- Update to version 0.8.16:
  * No changelog available.
- Add a licence file to the package.
* Mon Jun 25 2018 sor.alexei@meowr.ru
- Use %%python_expand.
* Tue May 22 2018 mcepl@suse.com
- Clean up the SPEC file.
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Wed Jun 28 2017 sor.alexei@meowr.ru
- Fix building on openSUSE older than openSUSE Leap 15.x.
* Tue Apr 18 2017 sor.alexei@meowr.ru
- Update to version 0.8.14:
  * Better Python handling.
  * Add Python3 support.
- Build for Python2 and Python3 both.
* Sat Apr 16 2016 sor.alexei@meowr.ru
- Update to 0.8.12.1:
  * Include autogen.sh in the tarball.
  * Better detection of Python2.
* Sat Feb 13 2016 sor.alexei@meowr.ru
- Update to 0.8.12:
  * Set minimal Python required version to 2.7.x.
  * Use Cython instead of Pyrex.
  * Add -fno-strict-aliasing to default CFLAGS to supress needless
    warnings.
* Sat Dec 19 2015 sor.alexei@meowr.ru
- Use a better upstream tarball.
* Mon Nov  9 2015 sor.alexei@meowr.ru
- Update to 0.8.9.
- Update dependencies.
- Remove newtocinit.diff: fixed upstream.
* Thu May 15 2014 ku.b@gmx.de
- remove %%fillup_prereq, %%py_requires macros
- remove ExclusiveArch: tag
* Thu May 31 2012 ku.b@gmx.de
- correct license format
* Sat Nov 12 2011 ku.b@gmx.de
- add the requirement for compiz with a version less than 0.9
* Mon Apr 26 2010 dimstar@opensuse.org
- Drop pkg-config file. We do not offer libs or anything else here.
* Fri Nov 13 2009 dimstar@opensuse.org
- Update to version 0.8.4
  + Reorder option types for consitency with compiz
  + SortSingleStringSetting fills the string restriction info
- spec file cleaned using spec-cleaner.
* Mon Sep 29 2008 rodrigo@novell.com
- Review and merge changes from X11:Compiz
* Wed Sep 17 2008 cyberorg@opensuse.org
- Release 0.7.8
- Handle lack of animation plugin
- Add support for restricted string options and extensions
* Tue Jul  1 2008 mhopf@suse.de
- Update from buildservice.
* Sat May 31 2008 cyberorg@opensuse.org
- Keep it in sync with compiz 0.7.6
* Mon Apr 14 2008 mhopf@suse.de
- Update from buildservice.
* Thu Apr  3 2008 cyberorg@cyberorg.info
- 0.7.4 release
- changes to keep it in sync with compiz release 0.7.4
* Sun Mar 16 2008 coolo@suse.de
- first define and then use %%version
* Tue Mar 11 2008 cyberorg@opensuse.org
- fix Provides/Obsoletes
* Fri Mar  7 2008 cyberorg@opensuse.org
- 0.7.2 development release
* Fri Feb  8 2008 cyberorg@cyberorg.info
- sync to latest git
* Tue Dec  4 2007 cyberorg@cyberorg.info
- sync to latest git
* Tue Oct 16 2007 cyberorg@cyberorg.info
- Update to release 0.6.0
* Mon Aug 27 2007 crrodriguez@suse.de
- more spec cleanup
- static libraries and libtool archives are always useless in python stuff
* Sat Aug 25 2007 cyberorg@cyberorg.info
- Idle settings parsing for better performance
- Improvements to key capture UI
* Fri Aug 24 2007 cyberorg@cyberorg.info
- Sync to the latest git.
- new action settings rework
* Mon Aug 13 2007 cyberorg@cyberorg.info
- Update to 0.5.2 release.
* Wed Aug  8 2007 schwab@suse.de
- Fix specfile.
* Tue Aug  7 2007 aj@suse.de
- Fix packaging problems.
* Mon Aug  6 2007 dreveman@suse.de
- Initial version of package
